@@ -16,7 +16,7 @@ if test "${2}" = "dynamic"; then
   echo "Dynamic {"
 fi
 
-num_workspaces=`xprop -root _NET_NUMBER_OF_DESKTOPS | /usr/bin/gawk '{ print $3 }'`
+num_workspaces=`xprop -root _NET_NUMBER_OF_DESKTOPS | /usr/bin/awk '{ print $3 }'`
 
 i=1;
 while test "${i}" -le "${num_workspaces}"; do
